# file_manager
una libreria para hacer puntos de guardado y mas
sus comandos son file_make_dir, file_make y file_delete
file_make_dir("nombre de carpeta")
file_make("carpeta en la que se creara el archivo","nombre del archivo junto a su extension digamos .py o .txt","el contenido del archivo","escribe un numero para identificarlo","su codigo de error")
file_delete("nombre de la carpeta o archivo")
